Package: attachment
Title: Deal with Dependencies
Version: 1.1.0
Authors@R: c(
    person("Vincent", "Guyader", , "vincent@thinkr.fr", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0003-0671-9270")),
    person("Sébastien", "Rochette", , "sebastienrochettefr@gmail.com", role = c("aut"),
           comment = c(ORCID = "0000-0002-1565-9313", "previous maintainer")),
    person("Murielle", "Delmotte", , "murielle@thinkr.fr", role = "aut",
           comment = c(ORCID = "0000-0002-1339-2424")),
    person("Swann", "Floc'hlay", , "swann@thinkr.fr", role = "aut",
           comment = c(ORCID = "0000-0003-1477-830X")),
    person("ThinkR", role = c("cph", "fnd"))
  )
Description: Manage dependencies during package development. This can
    retrieve all dependencies that are used in ".R" files in the "R/"
    directory, in ".Rmd" files in "vignettes/" directory and in 'roxygen2'
    documentation of functions. There is a function to update the
    "DESCRIPTION" file of your package with 'CRAN' packages or any other
    remote package.  All functions to retrieve dependencies of ".R"
    scripts and ".Rmd" or ".qmd" files can be used independently of a
    package development.
License: GPL-3
URL: https://thinkr-open.github.io/attachment/,
        https://github.com/ThinkR-open/attachment
BugReports: https://github.com/ThinkR-open/attachment/issues
VignetteBuilder: knitr
Config/fusen/version: 0.6.0
Config/Needs/website: ThinkR-open/thinkrtemplate
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
Language: en-US
Depends: R (>= 3.4)
Imports: cli, desc (>= 1.2.0), glue (>= 1.3.0), knitr (>= 1.20),
        magrittr (>= 1.5), rmarkdown (>= 1.10), roxygen2, stats,
        stringr (>= 1.3.1), utils, withr, yaml
Suggests: lifecycle, renv (>= 0.8.4), rstudioapi, testthat (>= 3.0.0)
NeedsCompilation: no
Packaged: 2026-08-19 14:45:00 UTC; ubuntu
Author: Vincent Guyader [cre, aut] (ORCID:
    <https://orcid.org/0000-0003-0671-9270>),
  Sébastien Rochette [aut] (ORCID:
    <https://orcid.org/0000-0002-1565-9313>, previous maintainer),
  Murielle Delmotte [aut] (ORCID:
    <https://orcid.org/0000-0002-1339-2424>),
  Swann Floc'hlay [aut] (ORCID: <https://orcid.org/0000-0003-1477-830X>),
  ThinkR [cph, fnd]
Maintainer: Vincent Guyader <vincent@thinkr.fr>
Repository: CRAN
Date/Publication: 2026-08-20 05:23:51 UTC
Built: R 4.5.2; ; 2026-08-20 09:07:13 UTC; unix
