Package: dummypackage
Title: What the Package Does (one line, title case)
Version: 0.0.0.9000
Authors@R: 
    person("First", "Last", , "first.last@example.com", role = c("aut", "cre"))
Description: What the package does (one paragraph).
License: What license is it under?
Depends: 
    R (>= 3.5.0)
Imports: 
    magrittr,
    stats
Suggests: 
    glue,
    knitr,
    rmarkdown,
    testthat,
    utils,
    stringr
LinkingTo:
    Rcpp
VignetteBuilder: 
    knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.1
