# Generated by roxygen2: do not edit by hand

export("%>%")
export(att_amend_desc)
export(att_from_data)
export(att_from_description)
export(att_from_examples)
export(att_from_namespace)
export(att_from_qmd)
export(att_from_qmds)
export(att_from_rmd)
export(att_from_rmds)
export(att_from_rscript)
export(att_from_rscripts)
export(att_to_desc_from_is)
export(att_to_desc_from_pkg)
export(att_to_description)
export(complete_remote_branch)
export(create_dependencies_file)
export(create_renv_for_dev)
export(create_renv_for_prod)
export(find_remotes)
export(install_from_description)
export(install_if_missing)
export(set_remotes_to_desc)
importFrom(cli,cat_bullet)
importFrom(desc,description)
importFrom(glue,glue)
importFrom(glue,glue_collapse)
importFrom(knitr,purl)
importFrom(magrittr,"%>%")
importFrom(roxygen2,roxygenise)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(stringr,str_extract)
importFrom(stringr,str_extract_all)
importFrom(stringr,str_match)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_trim)
importFrom(utils,install.packages)
importFrom(utils,packageDescription)
importFrom(utils,read.table)
importFrom(yaml,read_yaml)
importFrom(yaml,write_yaml)
