# USE ONE OR THE OTHER and its gone.
touch Event-00001890-ITSProcessCommand_FindPoolAssignmentByPoolId.data
# rm Event-00001890-ITSProcessCommand_FindPoolAssignmentByPoolId.data

echo "Total Files"
ls | grep -c "$"

echo "data files"
ls | grep -c "data"

