% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/my_mean.R
\name{my_mean}
\alias{my_mean}
\title{my_mean}
\usage{
my_mean(x)
}
\arguments{
\item{x}{a vector}
}
\description{
my_mean
}
\examples{
# example code
library(utils)
data("fruit", package = "stringr")
}
